@@ -2,7 +2,7 @@
 STLK <- function(X,r=NULL,t=NULL,nxy=10){
   if (!inherits(X, "stlpp")) stop("X should be from class stlpp")
 
-  Y <- as.stlpp.lpp(X)
+  Y <- as.lpp.stlpp(X)
   l <- domain(Y)
   tleng <- summary(l)$totlength
   n <- npoints(X)
